# TPK4186 - Advanced Tools for Performance Engineering
# PreparingEmails.py
# by Antoine Rauzy
# Copyrights (c) 2019-2020 NTNU
#
# This file is part of the educational material provided to NTNU students registered to the course TPK4186.
# It is licensed under a Creative Commons Attribution-NonCommercial 4.0 International License.
# For details about this license, see https://creativecommons.org/licenses/by-nc/4.0/.

# Table of Contents
# -----------------
# 1. Required modules
# 2. Creation of the folder 'Students'
# 3. Printing of the email for a student
# 4. Processing file 'Students.csv'

# 1. Required modules
# -------------------
import sys
import os
import re

# 2. Creation of the folder 'Students'
# ------------------------------------
def CreateFolder(folderName):
  if os.path.exists(folderName):
    if os.path.isdir(folderName):
      return 0
    sys.stderr.write("Impossible to create the folder " + folderName + "\n")
    sys.stderr.flush()
    return 1
  os.mkdir(folderName)

# 3. Printing of the email for a student
# --------------------------------------
def PrintEmailToStudent(templateFileName, firstName, familyName, email, courses, targetFolderName):
  try:
    templateFile = open(templateFileName, "r")
  except:
    sys.stderr.write("Unable to open template file " + templateFileName + "\n")
    sys.stderr.flush()
    return 1
  try:
    targetPath = os.path.join(targetFolderName, familyName + firstName + ".txt")
    targetFile = open(targetPath, "w")
  except:
    sys.stderr.write("Unable to open target file " + targetPath + "\n")
    sys.stderr.flush()
    templateFile.close()
    return 1
  courseString = ""
  first = True
  for course in courses:
    if first:
      first = False
    else:
      courseString += ", "
    courseString += course
  for templateLine in templateFile:
    targetLine = templateLine.rstrip()
    targetLine = re.sub(r"STUDENT_FIRST_NAME", firstName, targetLine)
    targetLine = re.sub(r"STUDENT_FAMILY_NAME", familyName, targetLine)
    targetLine = re.sub(r"STUDENT_EMAIL", email, targetLine)
    targetLine = re.sub(r"STUDENT_COURSES", courseString, targetLine)
    targetFile.write(targetLine + "\n")
  templateFile.close()
  targetFile.flush()
  targetFile.close()

# 4. Processing file 'Students.csv'
def ProcessStudentFile(studentFileName, templateFileName, targetFolderName):
  try:
    studentFile = open(studentFileName, "r")
  except:
    sys.stderr.write("Unable to open student file " + studentFileName + "\n")
    sys.stderr.flush()
    return 1
  for line in studentFile:
    line = line.rstrip()
    tokens = re.split(r"\t", line)
    familyName = tokens[1]
    firstName = tokens[2]
    email = tokens[4]
    courses = re.split(r"[ ]*,[ ]*", tokens[5])
    PrintEmailToStudent(templateFileName, firstName, familyName, email, courses, targetFolderName)
  studentFile.close()

studentFileName = "Students.csv"
templateFileName = "EmailTemplate.txt"
targetFolderName = "Students"
CreateFolder(targetFolderName)
ProcessStudentFile(studentFileName, templateFileName, targetFolderName)
