# TPK4186 - Advanced Tools for Performance Engineering
# SubstitutionCipher.py
# by Antoine Rauzy
# Copyrights (c) 2019-2020 NTNU
#
# This file is part of the educational material provided to NTNU students registered to the course TPK4186.
# It is licensed under a Creative Commons Attribution-NonCommercial 4.0 International License.
# For details about this license, see https://creativecommons.org/licenses/by-nc/4.0/.


# Required modules
import sys
import re

# Open the input file
inputFileName = "Article1&2.txt"
inputFile = open(inputFileName, "r")
if inputFile==None:
  sys.stderr.write("Unable to open file '%s'\n" % inputFileName)
  sys.exit()

# Open the output file
outputFileName = "Article1&2-decyphered.txt"
outputFile = open(outputFileName, "w")
if outputFile==None:
  sys.stderr.write("Unable to open file '%s'\n" % outputFileName)
  inputFile.close()
  sys.exit()

# Ciphering substitution
cipheringSubstitution = {
  "A": "Z",
  "B": "A",
  "C": "B",
  "D": "C",
  "E": "D",
  "F": "E",
  "G": "F",
  "H": "G",
  "I": "H",
  "J": "I",
  "K": "J",
  "L": "K",
  "M": "L",
  "N": "M",
  "O": "N",
  "P": "O",
  "Q": "P",
  "R": "Q",
  "S": "R",
  "T": "S",
  "U": "T",
  "V": "U",
  "W": "V",
  "X": "W",
  "y": "X",
  "Z": "Y",
  "a": "b",
  "b": "c",
  "c": "d",
  "d": "e",
  "e": "f",
  "f": "g",
  "g": "h",
  "h": "i",
  "i": "j",
  "j": "k",
  "k": "l",
  "l": "m",
  "m": "n",
  "n": "o",
  "o": "p",
  "p": "q",
  "q": "r",
  "r": "s",
  "s": "u",
  "u": "v",
  "v": "w",
  "w": "x",
  "x": "y",
  "y": "z",
  "z": "a",
  ",": ";",
  ";": ".",
  ".": ",",
  " ": "+",
  "+": " "
  }

# Deciphering substitution
decipheringSubstitution = dict()
for key in cipheringSubstitution:
  value = cipheringSubstitution[key]
  decipheringSubstitution[value] = key

# Read the input file line by line
# Add an extra newline character after each dot
# Write the result into the output file
for inputLine in inputFile:
  outputLine = ""
  for inputChar in inputLine:
    outputChar = cipheringSubstitution.get(inputChar, inputChar)
    outputLine += outputChar
  outputFile.write(outputLine)

# Close the input and output files
outputFile.close()
inputFile.close()
